package com.miaxis.app.report.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.miaxis.app.report.mapper.ReportImagesMapper;
import com.miaxis.app.report.domain.ReportImages;
import com.miaxis.app.report.service.IReportImagesService;

/**
 * 用户照片Service业务层处理
 *
 * @author miaxis
 * @date 2021-01-06
 */
@Service
public class ReportImagesServiceImpl extends ServiceImpl<ReportImagesMapper, ReportImages> implements IReportImagesService {
    @Autowired
    private ReportImagesMapper reportImagesMapper;

    /**
     * 查询用户照片
     *
     * @param id 用户照片ID
     * @return 用户照片
     */
    @Override
    public ReportImages selectReportImagesById(Long id){
        return reportImagesMapper.selectReportImagesById(id);
    }

    /**
     * 查询用户照片列表
     *
     * @param reportImages 用户照片
     * @return 用户照片
     */
    @Override
    public List<ReportImages> selectReportImagesList(ReportImages reportImages){
        return reportImagesMapper.selectReportImagesList(reportImages);
    }

    /**
     * 新增用户照片
     *
     * @param reportImages 用户照片
     * @return 结果
     */
    @Override
    public int insertReportImages(ReportImages reportImages){
        reportImages.setCreateTime(DateUtils.getNowDate());
        return reportImagesMapper.insertReportImages(reportImages);
    }

    /**
     * 修改用户照片
     *
     * @param reportImages 用户照片
     * @return 结果
     */
    @Override
    public int updateReportImages(ReportImages reportImages){
        reportImages.setUpdateTime(DateUtils.getNowDate());
        return reportImagesMapper.updateReportImages(reportImages);
    }

    /**
     * 批量删除用户照片
     *
     * @param ids 需要删除的用户照片ID
     * @return 结果
     */
    @Override
    public int deleteReportImagesByIds(Long[] ids){
        return reportImagesMapper.deleteReportImagesByIds(ids);
    }

    /**
     * 删除用户照片信息
     *
     * @param id 用户照片ID
     * @return 结果
     */
    @Override
    public int deleteReportImagesById(Long id){
        return reportImagesMapper.deleteReportImagesById(id);
    }
}
